@@ -1,21 +1,7 @@
 /**
- * Copyright 2013 Albert Vaca <albertvaka@gmail.com>
+ * SPDX-FileCopyrightText: 2013 Albert Vaca <albertvaka@gmail.com>
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License or (at your option) version 3 or any later version
- * accepted by the membership of KDE e.V. (or its successor approved
- * by the membership of KDE e.V.), which shall act as a proxy
- * defined in Section 14 of version 3 of the license.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <https://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
 
 #include "batteryplugin.h"
@@ -29,26 +15,32 @@
 
 #include <core/daemon.h>
 
-#include "batterydbusinterface.h"
 #include "plugin_battery_debug.h"
 
 K_PLUGIN_CLASS_WITH_JSON(BatteryPlugin, "kdeconnect_battery.json")
 
 BatteryPlugin::BatteryPlugin(QObject* parent, const QVariantList& args)
     : KdeConnectPlugin(parent, args)
-    , batteryDbusInterface(new BatteryDbusInterface(device()))
 {
+}
 
-    //TODO: Our protocol should support a dynamic number of batteries.
-    //Solid::DeviceNotifier *notifier = Solid::DeviceNotifier::instance();
+int BatteryPlugin::charge() const
+{
+    return m_charge;
+}
 
+bool BatteryPlugin::isCharging() const
+{
+    return m_isCharging;
 }
 
 void BatteryPlugin::connected()
 {
+    // We've just connected. Request battery information from the remote device...
     NetworkPacket np(PACKET_TYPE_BATTERY_REQUEST, {{QStringLiteral("request"),true}});
     sendPacket(np);
 
+    // ...and then figure out whether we have any batteries
     const auto batteryDevice = Solid::DeviceInterface::Type::Battery;
     const auto primary = Solid::Battery::BatteryType::PrimaryBattery;
 
@@ -61,18 +53,22 @@ void BatteryPlugin::connected()
         return;
     }
 
+    // Ok, there's at least one. Let's assume it will remain attached (for most laptops
+    // and desktops, this is a safe assumption).
     const Solid::Battery* chosen = batteries.first().as<Solid::Battery>();
 
-    connect(chosen, &Solid::Battery::chargeStateChanged, this, &BatteryPlugin::chargeChanged);
-    connect(chosen, &Solid::Battery::chargePercentChanged, this, &BatteryPlugin::chargeChanged);
+    connect(chosen, &Solid::Battery::chargeStateChanged, this, &BatteryPlugin::slotChargeChanged);
+    connect(chosen, &Solid::Battery::chargePercentChanged, this, &BatteryPlugin::slotChargeChanged);
 
     // Explicitly send the current charge
-    chargeChanged();
+    slotChargeChanged();
 }
 
-void BatteryPlugin::chargeChanged()
+void BatteryPlugin::slotChargeChanged()
 {
-
+    // Note: the NetworkPacket sent at the end of this method can reflect MULTIPLE batteries.
+    // We average the total charge against the total number of batteries, which in practice
+    // seems to work out ok.
     bool isAnyBatteryCharging = false;
     int batteryQuantity = 0;
     int cumulativeCharge = 0;
@@ -85,8 +81,8 @@ void BatteryPlugin::chargeChanged()
     for (auto device : batteries) {
         const Solid::Battery* battery = device.as<Solid::Battery>();
 
-        // Don't look at batteries that have been detached
-        if (battery->isPresent()) {
+        // Don't look at batteries that can be easily detached
+        if (battery->isPowerSupply()) {
             batteryQuantity++;
             cumulativeCharge += battery->chargePercent();
             if (battery->chargeState() == Solid::Battery::ChargeState::Charging) {
@@ -109,10 +105,11 @@ void BatteryPlugin::chargeChanged()
     status.set(QStringLiteral("currentCharge"), cumulativeCharge / batteryQuantity);
     // FIXME: In future, we should consider sending an array of battery objects
     status.set(QStringLiteral("batteryQuantity"), batteryQuantity);
-    // We consider primary battery to be low if it will only last for 5 minutes or
-    // less. This doesn't necessarily work if (for example) Solid finds multiple
-    // batteries.
-    if (chosen->remainingTime() < 600 && chosen->chargeState() == Solid::Battery::ChargeState::Discharging) {
+    // We consider the primary battery to be low if it won't last another 10 minutes.
+    // This doesn't necessarily work if (for example) Solid finds multiple batteries.
+    // FIXME: In future, we should check system settings instead of hardcoding an
+    // amount of time.
+    if (chosen->timeToEmpty() < 600 && chosen->chargeState() == Solid::Battery::ChargeState::Discharging) {
         status.set(QStringLiteral("thresholdEvent"), (int)ThresholdBatteryLow);
     } else {
         status.set(QStringLiteral("thresholdEvent"), (int)ThresholdNone);
@@ -120,35 +117,24 @@ void BatteryPlugin::chargeChanged()
     sendPacket(status);
 }
 
-BatteryPlugin::~BatteryPlugin()
-{
-    //FIXME: Qt dbus does not allow to remove an adaptor! (it causes a crash in
-    // the next dbus access to its parent). The implication of not deleting this
-    // is that disabling the plugin does not remove the interface (that will
-    // return outdated values) and that enabling it again instantiates a second
-    // adaptor. This is also a memory leak until the entire device is destroyed.
-
-    //batteryDbusInterface->deleteLater();
-}
-
 bool BatteryPlugin::receivePacket(const NetworkPacket& np)
 {
-    bool isCharging = np.get<bool>(QStringLiteral("isCharging"), false);
-    int currentCharge = np.get<int>(QStringLiteral("currentCharge"), -1);
-    int thresholdEvent = np.get<int>(QStringLiteral("thresholdEvent"), (int)ThresholdNone);
+    m_isCharging = np.get<bool>(QStringLiteral("isCharging"), false);
+    m_charge = np.get<int>(QStringLiteral("currentCharge"), -1);
+    const int thresholdEvent = np.get<int>(QStringLiteral("thresholdEvent"), (int)ThresholdNone);
 
-    if (batteryDbusInterface->charge() != currentCharge
-        || batteryDbusInterface->isCharging() != isCharging
-    ) {
-        batteryDbusInterface->updateValues(isCharging, currentCharge);
-    }
+    Q_EMIT refreshed();
 
-    if ( thresholdEvent == ThresholdBatteryLow && !isCharging ) {
-        Daemon::instance()->sendSimpleNotification(QStringLiteral("batteryLow"), i18nc("device name: low battery", "%1: Low Battery", device()->name()), i18n("Battery at %1%", currentCharge), QStringLiteral("battery-040"));
+    if (thresholdEvent == ThresholdBatteryLow && !m_isCharging) {
+        Daemon::instance()->sendSimpleNotification(QStringLiteral("batteryLow"), i18nc("device name: low battery", "%1: Low Battery", device()->name()), i18n("Battery at %1%", m_charge), QStringLiteral("battery-040"));
     }
 
     return true;
+}
 
+QString BatteryPlugin::dbusPath() const
+{
+    return QStringLiteral("/modules/kdeconnect/devices/") + device()->id() + QStringLiteral("/battery");
 }
 
 #include "batteryplugin.moc"
