@@ -1,22 +1,8 @@
 /**
- * Copyright 2013 Albert Vaca <albertvaka@gmail.com>
- * Copyright 2018 Simon Redman <simon@ergotech.com>
+ * SPDX-FileCopyrightText: 2013 Albert Vaca <albertvaka@gmail.com>
+ * SPDX-FileCopyrightText: 2018 Simon Redman <simon@ergotech.com>
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License or (at your option) version 3 or any later version
- * accepted by the membership of KDE e.V. (or its successor approved
- * by the membership of KDE e.V.), which shall act as a proxy
- * defined in Section 14 of version 3 of the license.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <https://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
 
 #ifndef CONVERSATIONSDBUSINTERFACE_H
@@ -39,6 +25,11 @@ class Device;
 
 Q_DECLARE_LOGGING_CATEGORY(KDECONNECT_CONVERSATIONS)
 
+// There is some amount of overhead and delay to making a request, so make sure to request at least a few
+#define MIN_NUMBER_TO_REQUEST 25
+// Some low-water mark after which we want to fill the cache
+#define CACHE_LOW_WATER_MARK_PERCENT 10
+
 class ConversationsDbusInterface
     : public QDBusAbstractAdaptor
 {
@@ -58,11 +49,17 @@ public:
     QList<ConversationMessage> getConversation(const qint64& conversationID) const;
 
     /**
-     * Get all of the messages in the requested conversation from the remote device
-     * TODO: Make interface capable of requesting smaller window of messages
+     * Get some new messages for the requested conversation from the remote device
+     * Requests a quantity of new messages equal to the current number of messages in the conversation
      */
     void updateConversation(const qint64& conversationID);
 
+    /**
+     * Gets the path of the succesfully downloaded attachment file and send
+     * update to the conversationModel
+     */
+    void attachmentDownloaded(const QString &filePath, const QString &fileName);
+
 public Q_SLOTS:
     /**
      * Return a list of the first message in every conversation
@@ -85,18 +82,23 @@ public Q_SLOTS:
     /**
      * Send a new message to this conversation
      */
-    void replyToConversation(const qint64& conversationID, const QString& message);
+    void replyToConversation(const qint64& conversationID, const QString& message, const QVariantList& attachmentUrls);
 
     /**
      * Send a new message to the contact having no previous coversation with
      */
-    void sendWithoutConversation(const QDBusVariant& addressList, const QString& message);
+    void sendWithoutConversation(const QVariantList& addressList, const QString& message, const QVariantList& attachmentUrls);
 
     /**
      * Send the request to the Telephony plugin to update the list of conversation threads
      */
     void requestAllConversationThreads();
 
+    /**
+     * Send the request to SMS plugin to fetch original attachment file path
+     */
+    void requestAttachmentFile(const qint64& partID, const QString& uniqueIdentifier);
+
 Q_SIGNALS:
     /**
      * Emitted whenever a conversation with no cached messages is added, either because the cache
@@ -121,12 +123,16 @@ Q_SIGNALS:
      */
     Q_SCRIPTABLE void conversationLoaded(qint64 conversationID, quint64 messageCount);
 
+    /**
+     * Emitted whenever we have succesfully download a requested attachment file from the phone
+     */
+    Q_SCRIPTABLE void attachmentReceived(QString filePath, QString fileName);
+
 private /*methods*/:
     QString newId(); //Generates successive identifiers to use as public ids
 
 private /*attributes*/:
     const QString m_device;
-    KdeConnectPlugin* m_plugin;
 
     /**
      * Mapping of threadID to the messages which make up that thread
